spoon.ber.tag.Tag

Package spoon :: Package ber :: Module tag :: Class Tag |
[show private | hide private]
[frames | no frames]

## Type Tag

    object --+
             |
            Tag

Representation of the header of an ASN.1 object. This includes the class (universal, application, context, or private), the type tag (any integer), and size.

Method Summary
| `__init__(self, tag_class, tag, size, container, _bytes_read)`
| `__cmp__(self, other)`
| `__hash__(self)`
| `__len__(self)`
| `__repr__(self)`
| `from_stream(fd)` (Static method)
| `from_tag(t, size)` (Static method)
| ``is_terminator`(self)` Return `True` if this tag is the special type used to terminate indefinite-length sequences (type 0, length 0).
| ``make_terminator`()` Return a tag that can be used to terminate indefinite-length sequences. (Static method)
| `write(self, fd)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Property Summary
| `container`
| `size`
| `tag`
| `tag_class`

Instance Method Details

### is_terminator(self) Return `True` if this tag is the special type used to terminate indefinite-length sequences (type 0, length 0).

Static Method Details

### make_terminator() Return a tag that can be used to terminate indefinite-length sequences.

Property Details

### container Get Method: unknown--1480426164(...)

### size Get Method: unknown--1480426220(...)

### tag Get Method: unknown--1480426276(...)

### tag_class Get Method: unknown--1480426332(...)

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net